RequestItem class

Annotations

Constructors

RequestItem({required String id, required Creator creator, required String title, required String description, required DateTime createdAt, required DateTime updatedAt, List<Comment> comments = const [], List<Vote> votes = const [], RequestStatus status = RequestStatus.none})
const
RequestItem.fromJson(Map<String, dynamic> json)
factory

Properties

comments List<Comment>
final
createdAt DateTime
final
creator Creator
final
description String
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status RequestStatus
final
title String
final
updatedAt DateTime
final
votes List<Vote>
final

Methods

copyWith({String? id, Creator? creator, String? title, String? description, DateTime? createdAt, DateTime? updatedAt, List<Comment>? comments, List<Vote>? votes, RequestStatus? status}) RequestItem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override